# Contributing

We welcome contributions from anyone beginner or advanced. Please before working on some feature

* search through the past issues, your concern may have been raised by others in the past. Check through
closed issues as well.
* if there is no open issue for your feature request please open one up to coordinate all collaborators
* write your feature
* submit a pull request on this repo with:
  * a brief description
  * **detail of the expected change(s) in behaviour**
  * how to test it (if it's not obvious)
  
Ask someone to test it.
